# pydmc/core
This group of modules are meant to be run either on HPC or locally

## comp
- manipulate chemical formulas

## hulls
- for generating and analyzing convex hull phase diagrams
    - serial or parallel

## mag
- generate magnetic configurations

## query
- get data from databases
    - currently only supports querying the Materials Project

## struc
- manipulate crystal structures



